//=============================================================================
//  "Open in ShakuViewer" plugin for MuseScore 3
//
//  Opens the current score in ShakuViewer.
//
//  Copyright (c) 2015-2020 Razvan Beuran
//=============================================================================

import QtQuick 2.2
import MuseScore 3.0

MuseScore {
    version:  "3.0"
    description: "Opens the current score in ShakuViewer. For information about ShakuViewer see: https://sites.google.com/site/razvanswebsite/software/shakuviewer"
    menuPath: "Plugins.Open in ShakuViewer"

    QProcess {
        id: process
    }

    onRun: {

        //////////////////////////////////////////////////////////
        // IMPORTANT
        // Change the variable SV_PATH below to indicate the location where
        // the ShakuViewer software is installed on your computer
        // * Example for Windows (use '\\' or '/' for each backslash character)
        // var SV_PATH = "C:\\Users\\XYZ\\ShakuViewer-0.4";
        // * Example for macOS and Linux
        // var SV_PATH = "/Users/XYZ/ShakuViewer-0.4";
        var SV_PATH = "/PATH/TO/ShakuViewer";
        //////////////////////////////////////////////////////////

        // Check whether the current score is defined
        if (typeof curScore === 'undefined' || curScore == null) 
        {
            console.log("ERROR: No score is currently open => quit");
            Qt.quit(); // Needed to cleanly end process execution
            return; // Needed to actually return from script
        }

        // Define local variables
        var fileBase = SV_PATH + "/plugin";
        var musicXMLExtension = "musicxml";
        var scoreName = fileBase + "_score." + musicXMLExtension;
        //var stderrName = fileBase + "_stderr.txt";
        //var stdoutName = fileBase + "_stdout.txt";

        // Save the current score in MusicXML format
        console.log("INFO: Write score '" + curScore.name + "' to MusicXML file '" + scoreName + "'");
        writeScore(curScore, scoreName, musicXMLExtension);

        // Prepare command to start java process
        var javaExecutable = "java";
        var javaOption = "-jar";
        var javaFile = SV_PATH + "/ShakuViewer.jar";
        var javaCommand = javaExecutable + ' ' + javaOption + ' "' + javaFile + '" "' + scoreName + '"';

        // Start the java process
        console.log("INFO: Start ShakuViewer: " + javaCommand);
        process.start(javaCommand);

        // Configure sending output to files
        //var val = process.waitForFinished(10000);
        //if (val)
        //    console.log(process.readAllStandardOutput());
        //}

        Qt.quit()
    }
}
